@@ -2,8 +2,7 @@ context("solve")
 
 test_that("x=RasterLayer, y=RasterStack (single zone)", {
   skip_on_cran()
-  skip_on_ci()
-  skip_if_not(any_solvers_installed())
+  skip_if_no_fast_solvers_installed()
   # simulate data
   costs <- raster::raster(matrix(c(1, 2, NA, 3), ncol = 4))
   spp <- raster::stack(raster::raster(matrix(c(1, 2, 0, 0), ncol = 4)),
@@ -24,8 +23,7 @@ test_that("x=RasterLayer, y=RasterStack (single zone)", {
 
 test_that("x=RasterStack, y=ZonesRaster (multiple zones)", {
   skip_on_cran()
-  skip_on_ci()
-  skip_if_not(any_solvers_installed())
+  skip_if_no_fast_solvers_installed()
   # simulate data
   costs <- raster::stack(
     raster::raster(matrix(c(1,  2,  NA, 3, 100, 100, NA), ncol = 7)),
@@ -50,8 +48,7 @@ test_that("x=RasterStack, y=ZonesRaster (multiple zones)", {
 
 test_that("x=SpatialPolygonsDataFrame, y=RasterStack (single zone)", {
   skip_on_cran()
-  skip_on_ci()
-  skip_if_not(any_solvers_installed())
+  skip_if_no_fast_solvers_installed()
   # make data
   costs <- raster::raster(matrix(1:4, byrow = TRUE, ncol = 2)) %>%
            as("SpatialPolygonsDataFrame")
@@ -74,8 +71,7 @@ test_that("x=SpatialPolygonsDataFrame, y=RasterStack (single zone)", {
 
 test_that("x=SpatialPolygonsDataFrame, y=ZonesRaster (multiple zones)", {
   skip_on_cran()
-  skip_on_ci()
-  skip_if_not(any_solvers_installed())
+  skip_if_no_fast_solvers_installed()
   # make data
   costs <- raster::raster(matrix(1:7, ncol = 7)) %>%
            as("SpatialPolygonsDataFrame")
@@ -102,8 +98,7 @@ test_that("x=SpatialPolygonsDataFrame, y=ZonesRaster (multiple zones)", {
 
 test_that("x=SpatialPolygonsDataFrame, y=character (single zone)", {
   skip_on_cran()
-  skip_on_ci()
-  skip_if_not(any_solvers_installed())
+  skip_if_no_fast_solvers_installed()
   # make data
   costs <- raster::raster(matrix(1:4, byrow = 2, ncol = 2)) %>%
            as("SpatialPolygonsDataFrame")
@@ -124,8 +119,7 @@ test_that("x=SpatialPolygonsDataFrame, y=character (single zone)", {
 
 test_that("x=SpatialPolygonsDataFrame, y=ZonesCharacter (multiple zones)", {
   skip_on_cran()
-  skip_on_ci()
-  skip_if_not(any_solvers_installed())
+  skip_if_no_fast_solvers_installed()
   # make data
   costs <- raster::raster(matrix(1:7, ncol = 7)) %>%
            as("SpatialPolygonsDataFrame")
@@ -151,8 +145,7 @@ test_that("x=SpatialPolygonsDataFrame, y=ZonesCharacter (multiple zones)", {
 
 test_that("x=sf, y=RasterStack (single zone)", {
   skip_on_cran()
-  skip_on_ci()
-  skip_if_not(any_solvers_installed())
+  skip_if_no_fast_solvers_installed()
   # make data
   costs <- raster::raster(matrix(1:4, byrow = TRUE, ncol = 2)) %>%
            as("SpatialPolygonsDataFrame") %>%
@@ -176,8 +169,7 @@ test_that("x=sf, y=RasterStack (single zone)", {
 
 test_that("x=sf, y=ZonesRaster (multiple zones)", {
   skip_on_cran()
-  skip_on_ci()
-  skip_if_not(any_solvers_installed())
+  skip_if_no_fast_solvers_installed()
   # make data
   costs <- raster::raster(matrix(1:7, ncol = 7)) %>%
            as("SpatialPolygonsDataFrame") %>%
@@ -205,8 +197,7 @@ test_that("x=sf, y=ZonesRaster (multiple zones)", {
 
 test_that("x=sf, y=character (single zone)", {
   skip_on_cran()
-  skip_on_ci()
-  skip_if_not(any_solvers_installed())
+  skip_if_no_fast_solvers_installed()
   # make data
   costs <- raster::raster(matrix(1:4, byrow = 2, ncol = 2)) %>%
            as("SpatialPolygonsDataFrame") %>%
@@ -228,8 +219,7 @@ test_that("x=sf, y=character (single zone)", {
 
 test_that("x=sf, y=ZonesCharacter (multiple zones)", {
   skip_on_cran()
-  skip_on_ci()
-  skip_if_not(any_solvers_installed())
+  skip_if_no_fast_solvers_installed()
   # make data
   costs <- raster::raster(matrix(1:7, ncol = 7)) %>%
            as("SpatialPolygonsDataFrame") %>%
@@ -256,8 +246,7 @@ test_that("x=sf, y=ZonesCharacter (multiple zones)", {
 
 test_that("x=data.frame, y=data.frame (single zone)", {
   skip_on_cran()
-  skip_on_ci()
-  skip_if_not(any_solvers_installed())
+  skip_if_no_fast_solvers_installed()
   # simulate data
   pu <- data.frame(id = seq_len(4), cost = c(1, 2, NA, 3))
   species <- data.frame(id = seq_len(2), name = letters[1:2])
@@ -277,8 +266,7 @@ test_that("x=data.frame, y=data.frame (single zone)", {
 
 test_that("x=data.frame, y=data.frame (multiple zones)", {
   skip_on_cran()
-  skip_on_ci()
-  skip_if_not(any_solvers_installed())
+  skip_if_no_fast_solvers_installed()
   # simulate data
   costs <- data.frame(id = seq_len(7),
                       cost_1 = c(1,  2,  NA, 3, 100, 100, NA),
@@ -308,8 +296,7 @@ test_that("x=data.frame, y=data.frame (multiple zones)", {
 
 test_that("x=numeric, y=data.frame (single zone)", {
   skip_on_cran()
-  skip_on_ci()
-  skip_if_not(any_solvers_installed())
+  skip_if_no_fast_solvers_installed()
   # simulate data
   pu <- data.frame(id = seq_len(4), cost = c(1, NA, 1000, 3))
   species <- data.frame(id = seq_len(2), name = letters[1:2])
@@ -328,8 +315,7 @@ test_that("x=numeric, y=data.frame (single zone)", {
 
 test_that("x=matrix, y=data.frame (multiple zones)", {
   skip_on_cran()
-  skip_on_ci()
-  skip_if_not(any_solvers_installed())
+  skip_if_no_fast_solvers_installed()
   # simulate data
   costs <- data.frame(id = seq_len(7),
                       cost_1 = c(1,  2,  NA, 3, 100, 100, NA),
@@ -355,24 +341,6 @@ test_that("x=matrix, y=data.frame (multiple zones)", {
   expect_equal(s[, "z2"], c(0, 0, 0,  0, 1, 0, NA))
 })
 
-test_that("silent output when verbose=FALSE", {
-  skip_on_cran()
-  skip_on_ci()
-  skip_if_not_installed("Rsymphony")
-  # simulate data
-  costs <- raster::raster(matrix(c(1, 2, NA, 3), ncol = 4))
-  spp <- raster::stack(raster::raster(matrix(c(1, 2, 0, 0), ncol = 4)),
-                       raster::raster(matrix(c(NA, 0, 1, 1), ncol = 4)))
-  # make problem
-  p <- problem(costs, spp) %>%
-       add_min_set_objective() %>%
-       add_absolute_targets(c(1, 1)) %>%
-       add_binary_decisions() %>%
-       add_rsymphony_solver(gap = 0, verbose = FALSE)
-  # solve problem silently
-  expect_silent(solve(p))
-})
-
 test_that("numerical instability (error when force = FALSE)", {
   data(sim_pu_polygons, sim_features)
   sim_pu_polygons$cost[1] <- 1e+35
@@ -380,21 +348,20 @@ test_that("numerical instability (error when force = FALSE)", {
     add_min_set_objective() %>%
     add_relative_targets(0.1) %>%
     add_binary_decisions() %>%
-    add_default_solver(time_limit = 5, verbose = FALSE)
+    add_default_solver(first_feasible = TRUE, verbose = FALSE)
   expect_warning(expect_error(solve(p)))
 })
 
 test_that("numerical instability (solution when force = TRUE)", {
   skip_on_cran()
-  skip_on_ci()
-  skip_if_not(any_solvers_installed())
+  skip_if_no_fast_solvers_installed()
   # make data
   data(sim_pu_polygons, sim_features)
-  sim_pu_polygons$cost[1] <- 1e+35
+  sim_pu_polygons$cost[1] <- 1e+20
   p <- problem(sim_pu_polygons, sim_features, "cost") %>%
     add_min_set_objective() %>%
     add_relative_targets(0.1) %>%
     add_binary_decisions() %>%
-    add_default_solver(time_limit = 5, verbose = FALSE)
+    add_default_solver(first_feasible = TRUE, verbose = FALSE)
   expect_warning(expect_is(solve(p, force = TRUE), "SpatialPolygonsDataFrame"))
 })
